==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge.md <==
# AwsCloudWanCoreNetworkEdge


```text
aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge
```

```text
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')
```



| Illustration | AwsCloudWanCoreNetworkEdge | AwsCloudWanCoreNetworkEdgeCard | AwsCloudWanCoreNetworkEdgeGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge.png) | ![illustration for AwsCloudWanCoreNetworkEdge](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge.Local.png) | ![illustration for AwsCloudWanCoreNetworkEdgeCard](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdgeCard.Local.png) | ![illustration for AwsCloudWanCoreNetworkEdgeGroup](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdgeGroup.Local.png) |




## AwsCloudWanCoreNetworkEdge

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdge
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdge('AwsCloudWanCoreNetworkEdge', 'Aws Cloud Wan Core Network Edge', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdge
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdge('AwsCloudWanCoreNetworkEdge', 'Aws Cloud Wan Core Network Edge', 'an optional tech label')
@enduml
```

## AwsCloudWanCoreNetworkEdgeCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdgeCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdgeCard('AwsCloudWanCoreNetworkEdgeCard', 'Aws Cloud Wan Core Network Edge Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdgeCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdgeCard('AwsCloudWanCoreNetworkEdgeCard', 'Aws Cloud Wan Core Network Edge Card', 'an optional description')
@enduml
```

## AwsCloudWanCoreNetworkEdgeGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdgeGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdgeGroup('AwsCloudWanCoreNetworkEdgeGroup', 'Aws Cloud Wan Core Network Edge Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdgeGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdgeGroup('AwsCloudWanCoreNetworkEdgeGroup', 'Aws Cloud Wan Core Network Edge Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge.md <==
# AwsCloudWanCoreNetworkEdge


```text
aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge
```

```text
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')
```



| Illustration | AwsCloudWanCoreNetworkEdge | AwsCloudWanCoreNetworkEdgeCard | AwsCloudWanCoreNetworkEdgeGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge.png) | ![illustration for AwsCloudWanCoreNetworkEdge](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge.Local.png) | ![illustration for AwsCloudWanCoreNetworkEdgeCard](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdgeCard.Local.png) | ![illustration for AwsCloudWanCoreNetworkEdgeGroup](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdgeGroup.Local.png) |




## AwsCloudWanCoreNetworkEdge

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdge
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdge('AwsCloudWanCoreNetworkEdge', 'Aws Cloud Wan Core Network Edge', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdge
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdge('AwsCloudWanCoreNetworkEdge', 'Aws Cloud Wan Core Network Edge', 'an optional tech label', 'an optional description')
@enduml
```

## AwsCloudWanCoreNetworkEdgeCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdgeCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdgeCard('AwsCloudWanCoreNetworkEdgeCard', 'Aws Cloud Wan Core Network Edge Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdgeCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdgeCard('AwsCloudWanCoreNetworkEdgeCard', 'Aws Cloud Wan Core Network Edge Card', 'an optional description')
@enduml
```

## AwsCloudWanCoreNetworkEdgeGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdgeGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdgeGroup('AwsCloudWanCoreNetworkEdgeGroup', 'Aws Cloud Wan Core Network Edge Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsCloudWanCoreNetworkEdgeGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsCloudWanCoreNetworkEdge')

' renders the element
AwsCloudWanCoreNetworkEdgeGroup('AwsCloudWanCoreNetworkEdgeGroup', 'Aws Cloud Wan Core Network Edge Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
